#include <detect.h>

/*----------------------------------------------------------------------*
 *	Function: LONG Time_f(t_kont,tc) - "floating point"		*
 *						for output		*
 *----------------------------------------------------------------------*
 *	Arguments:				        		*
 *         	        LONG t_kont - onset sample number	        *
 *			LONG tc - time correction	                *
 *----------------------------------------------------------------------*
 *	Returns:	LONG - onset time				*
 *----------------------------------------------------------------------*
 *	Fatal Errors:	This routine does not have fatal exits		*
 *----------------------------------------------------------------------*
 *	This routine calculates the onset time of the detected signal	*
 *	 from t_kont and tc.  One purpose of this routine is to cir-	*
 *	 cumvent floating point operations.				*
 *----------------------------------------------------------------------*/

LONG Time_f(t_kont,tc)
LONG t_kont;
LONG tc;

{
	LONG reftr,t_lval;

	if (con_ptr->sam_sec>0) {

		t_lval = t_kont/con_ptr->sam_sec;	/* Integer Seconds */
		reftr = t_kont - t_lval * con_ptr->sam_sec; 
                                                         /* Rem in samples */
                t_rval = reftr * con_ptr->ns_sam + etime.ns;

      /*	t_rval = reftr * con_ptr->ns_sam + etime.ns - tc - 468750000; */
                                      /* Rem ns, with filtering correction */
	} else {

	  printf(" Error in time_f:  sam_sec !> 0"); 

	}

/*---------------------Obtain remainder < 10^9 ns ---------------------*/

	while(t_rval >= con_ptr->ns_sec) {
		t_lval++;
		t_rval -= con_ptr->ns_sec; /* nanoseconds remainder */
	}

/*---------The time correction could have caused remainder < 0 -------*/

	while(t_rval <= - con_ptr->ns_sec) {
		t_lval--;
		t_rval += con_ptr->ns_sec; /* nanoseconds remainder */
	}

	if(t_rval < 0) {
		t_lval--;
		t_rval += con_ptr->ns_sec; /* nanoseconds remainder */
	}
	
/*--------------Integer seconds relative to header time--------------*/

	t_lval += etime.sec;

	return(t_lval);

}

#ifdef JNMCOMMENT

/***************************************************************************

			EXPLANATION OF VARIABLES

	etime.sec-- the reference time (seconds) of a record header.

	ns_sam --  sample rate expressed as nanoseconds per sample.

        ns_sec --  nanosecond per second.

	sam_sec -- digitizing rate of the current seismic data record.
		    Samples per second.

	reftr	-- remainder of integer division expressed in samples.

	tc	-- the time correction (nanoseconds) that is applied to the
		    reference onset.  For BB and SP data of the China System
		    tc = 500 (ms) or 0.

	t_kont	-- the number of samples from a reference time of a record
		    header to the reference onset of a signal.

	t_lval	-- the integer part of the onset time (seconds).

	t_rval	-- the remainder of the onset time expressed in nanoseconds.
*****************************************************************************/
#endif
