#include <detect.h>

/*----------------------------------------------------------------------*
 *	Function: VOID Wbuff() - Write buffers				*
 *----------------------------------------------------------------------*
 *	Arguments:	No arguments					*
 *----------------------------------------------------------------------*
 *	Returns:	Nothing (VOID)					*
 *----------------------------------------------------------------------*
 *	Fatal Errors:	This routine does not have fatal exits		*
 *----------------------------------------------------------------------*
 *	Wbuff updates buffers when an event might be in progress, but	*
 *	 not yet detected, ie when the event possible flag (epf) is	*
 *	 set = TRUE plus during the interval that is required for 	*
 *	 enough to data to estimate the period of the event.		*
 *----------------------------------------------------------------------*/

VOID Wbuff()
{

	if(con_ptr->lst_pt++ == B_M1) con_ptr->lst_pt = 0;
						/* increment lst_pt */

	con_ptr->buf_flg[con_ptr->lst_pt] = th_wt;     
	con_ptr->buf_sc[con_ptr->lst_pt] = con_ptr->sumdsc;
	con_ptr->buf_amp[con_ptr->lst_pt] = con_ptr->s_amp;
	con_ptr->buf_tim[con_ptr->lst_pt] = con_ptr->tim_of_max;
	con_ptr->buf_rec[con_ptr->lst_pt] = con_ptr->rec_of_max;  
	
	return;
}

#ifdef JNMCOMMENT
/****************************************************************************

			EXPLANATION OF VARIABLES

	buf_amp -- the circular buffer of size E_B that contains
		    the signed P-T values.  See Event.

	buf_flg -- the circular buffer of size E_B that contains
		    the weights (0,1,or 2) for each P-T value
		    of buf_amp. See Event.

	buf_rec -- the circular buffer of size E_B that contains
		    the (arbitrary) record number for each P-T
		    value of buf_amp.  See E_detect, P_one, Event.

	buf_sc	-- the circular buffer of size E_B that contains
		    the sum of the number of samples (time axis) from
		    initilization to each P-T of buf_amp.  See Event.

	buf_tim -- the circular buffer of size E_B that contains
		    a sample number for each P-T value of buf_amp.
		    The sample number is initialized at the beginning
		    of each record and is incremented for each 
		    seismic data sample. See E_detect, P_one, Event.  

	lst_pt	-- the index (within the circular buffers) of the 
		    last P-T value.  The circular buffers are of
		    size E_B, maximum index of B_M1.

	rec_of_max-- the (arbitrary) record number for each tim_of_max.
		      See P_one, Event.

	s_amp   -- the signed P-T amplitude.  See P_one.

	sumdsc  -- sum of the sample counts that was initialized
		    when the epf flag was set = TRUE, ie, when
		    the abbreviated buffers were downloaded in 
		    Event.  See Event.

	th_wt	-- a weight that is assigned by Event to each P-T
		    value of a possible signal.  Its values are
		    0, 1, or 2.

	tim_of_max-- the sample number of each P-T value of buf_amp.
		      The sample number is initialized at the beginning
		      of each record and is incremented for each 
		      seismic data sample thereafter.  tim_of_max is used to
		      time each P-T value.  See E_detect, P_one, Event.  

**************************************************************************/
#endif

