#ifndef TRIGMSG_HH
#define TRIGMSG_HH

#include "lmsg/Message.hh"
// #include "lmsg/DataMsg.hh"
#include "TrigProc.hh"
#include "TrigBase.hh"
#include "Segment.hh"

//-------------------------------------  Enumerate trigger manager messages
enum {
  tmm_Null= (2<<16),
  tmm_Register,
  tmm_Trigger,
  tmm_Close,
  tmm_ProcID,
  tmm_Ack,
  tmm_NAck,
  tmm_Segment,
  tmm_rmNode,
  tmm_reConfig
};

#define MgrName "Trigger Manager"

template<class T, unsigned int MsgID>
class TrigMgrMsg : public lmsg::Message {
public:
  TrigMgrMsg(void);
  ~TrigMgrMsg(void);
  TrigMgrMsg(const T& ival);
  TrigMgrMsg(lmsg::TransInput& istr);
  void setData(lmsg::TransInput& istr) throw(std::runtime_error);
  void getData(lmsg::TransOutput& ostr) const;
  const T& refValue(void) const;
  T& refValue(void);
  lmsg::size_type size(void) const;
  lmsg::MsgHeader::MsgType getType(void) const;

private:
  T mValue;
};

//-------------------------------------  Integer message class
typedef TrigMgrMsg<trig::TrigProc, tmm_Register> TMM_Register;
typedef TrigMgrMsg<trig::TrigBase, tmm_Trigger>  TMM_Trigger;
typedef TrigMgrMsg<trig::Segment,  tmm_Segment>  TMM_Segment;
typedef TrigMgrMsg<std::string,    tmm_ProcID>   TMM_ProcID;
typedef TrigMgrMsg<std::string,    tmm_Close>    TMM_Close;
typedef TrigMgrMsg<std::string,    tmm_rmNode>   TMM_RemNode;
typedef TrigMgrMsg<std::string,    tmm_reConfig> TMM_Reconfigure;

//-------------------------------------  Index request message
typedef lmsg::HdrOnlyMsg<tmm_Ack>   TMM_Ack;
typedef lmsg::HdrOnlyMsg<tmm_NAck>  TMM_NAck;

#endif  //  TRIGMSG_HH





